@@ -1,6 +1,7 @@
 import re
 import typing
 
+from wheezy.template.comp import Tuple
 from wheezy.template.typing import Builder, LexerRule, ParserRule, Token
 from wheezy.template.utils import find_balanced
 
@@ -48,13 +49,10 @@ class CodeExtension:
     """Includes support for embedded python code."""
 
     def __init__(self, token_start: str = "@") -> None:
-
         self.lexer_rules: typing.Mapping[int, LexerRule] = {
             300: (re.compile(r"\s*%s(?=\()" % token_start), code_token),
         }
 
     parser_rules: typing.Mapping[str, ParserRule] = {"code": parse_code}
 
-    builder_rules: typing.List[typing.Tuple[str, typing.Any]] = [
-        ("code", build_code)
-    ]
+    builder_rules: typing.List[Tuple[str, typing.Any]] = [("code", build_code)]
